# NOTE: Derived from blib/lib/BZS/TestModule.pm.
# Changes made here will be lost when autosplit again.
# See AutoSplit.pm.
package BZS::TestModule;

#line 22 "blib/lib/BZS/TestModule.pm (autosplit into blib/lib/auto/BZS/TestModule/prnt_split.al)"
sub prnt_split {
  print @_;
}

1;
# end of BZS::TestModule::prnt_split
